California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 82 - PUBLIC PRESCHOOL EDUCATION. TAX INCREASE ON INCOMES OVER $400,000 FOR INDIVIDUALS; $800,000 FOR COUPLES. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1283738 | SACRAMENTO PRE-SCHOOL FOR ALL, COMMITTEE FOR PROPOSITION 82, KEVIN MCCARTHY - SACRAMENTO CITY COUNCILMEMBER | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
971785 | YES ON 82, PRESCHOOL FOR ALL, A COALITION OF TEACHERS, EDUCATION ADVOCATES, BUSINESS LEADERS, AND SERVICE AND PUBLIC EMPLOYEE UNIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280726 | NONPROFITS FOR PRESCHOOL, SPONSORED BY PRESCHOOL CALIFORNIA, A PROJECT OF CIF OF THE SAN FRANCISCO FOUNDATION - YES OF PROP. 82 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1281134 | EARLY CARE AND EDUCATION FOR PRESCHOOL FOR ALL | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1273845 | CALIFORNIANS TO STOP HIGHER TAXES, A COALITION OF BUSINESS & TAXPAYER ORGANIZATIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1283698 | LAW ENFORCEMENT LEADERS FOR QUALITY PRESCHOOL - YES ON 82, SPONSORED BY FIGHT CRIME: INVEST IN KIDS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1282131 | STOP THE REINER INITIATIVE - NO ON 82, A COALITION OF EDUCATORS, BUSINESS AND TAXPAYER ORGANIZATIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1286192 | EDUCATORS FOR PRESCHOOL, YES ON PROPOSITION 82 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1286106 | YES ON 82, STANDING UP FOR OUR KIDS | SUPPORT